@@ -16,17 +16,20 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.cloud.bigquery_migration_v2alpha.services.migration_service import pagers
 from google.cloud.bigquery_migration_v2alpha.types import migration_entities
@@ -116,6 +119,42 @@ class MigrationServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return MigrationServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> MigrationServiceTransport:
         """Returns the transport used by the client instance.
@@ -188,6 +227,25 @@ class MigrationServiceAsyncClient:
     ) -> migration_entities.MigrationWorkflow:
         r"""Creates a migration workflow.
 
+        .. code-block::
+
+            from google.cloud import bigquery_migration_v2alpha
+
+            def sample_create_migration_workflow():
+                # Create a client
+                client = bigquery_migration_v2alpha.MigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_migration_v2alpha.CreateMigrationWorkflowRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.create_migration_workflow(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_migration_v2alpha.types.CreateMigrationWorkflowRequest, dict]):
                 The request object. Request to create a migration
@@ -221,7 +279,7 @@ class MigrationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, migration_workflow])
         if request is not None and has_flattened_params:
@@ -270,6 +328,25 @@ class MigrationServiceAsyncClient:
     ) -> migration_entities.MigrationWorkflow:
         r"""Gets a previously created migration workflow.
 
+        .. code-block::
+
+            from google.cloud import bigquery_migration_v2alpha
+
+            def sample_get_migration_workflow():
+                # Create a client
+                client = bigquery_migration_v2alpha.MigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_migration_v2alpha.GetMigrationWorkflowRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_migration_workflow(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_migration_v2alpha.types.GetMigrationWorkflowRequest, dict]):
                 The request object. A request to get a previously
@@ -296,7 +373,7 @@ class MigrationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -352,6 +429,26 @@ class MigrationServiceAsyncClient:
     ) -> pagers.ListMigrationWorkflowsAsyncPager:
         r"""Lists previously created migration workflow.
 
+        .. code-block::
+
+            from google.cloud import bigquery_migration_v2alpha
+
+            def sample_list_migration_workflows():
+                # Create a client
+                client = bigquery_migration_v2alpha.MigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_migration_v2alpha.ListMigrationWorkflowsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_migration_workflows(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.bigquery_migration_v2alpha.types.ListMigrationWorkflowsRequest, dict]):
                 The request object. A request to list previously created
@@ -379,7 +476,7 @@ class MigrationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -441,6 +538,22 @@ class MigrationServiceAsyncClient:
     ) -> None:
         r"""Deletes a migration workflow by name.
 
+        .. code-block::
+
+            from google.cloud import bigquery_migration_v2alpha
+
+            def sample_delete_migration_workflow():
+                # Create a client
+                client = bigquery_migration_v2alpha.MigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_migration_v2alpha.DeleteMigrationWorkflowRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_migration_workflow(request=request)
+
         Args:
             request (Union[google.cloud.bigquery_migration_v2alpha.types.DeleteMigrationWorkflowRequest, dict]):
                 The request object. A request to delete a previously
@@ -460,7 +573,7 @@ class MigrationServiceAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -510,6 +623,23 @@ class MigrationServiceAsyncClient:
         signaled if the state is anything other than DRAFT or
         RUNNING.
 
+
+        .. code-block::
+
+            from google.cloud import bigquery_migration_v2alpha
+
+            def sample_start_migration_workflow():
+                # Create a client
+                client = bigquery_migration_v2alpha.MigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_migration_v2alpha.StartMigrationWorkflowRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.start_migration_workflow(request=request)
+
         Args:
             request (Union[google.cloud.bigquery_migration_v2alpha.types.StartMigrationWorkflowRequest, dict]):
                 The request object. A request to start a previously
@@ -529,7 +659,7 @@ class MigrationServiceAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -584,6 +714,25 @@ class MigrationServiceAsyncClient:
     ) -> migration_entities.MigrationSubtask:
         r"""Gets a previously created migration subtask.
 
+        .. code-block::
+
+            from google.cloud import bigquery_migration_v2alpha
+
+            def sample_get_migration_subtask():
+                # Create a client
+                client = bigquery_migration_v2alpha.MigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_migration_v2alpha.GetMigrationSubtaskRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_migration_subtask(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_migration_v2alpha.types.GetMigrationSubtaskRequest, dict]):
                 The request object. A request to get a previously
@@ -613,7 +762,7 @@ class MigrationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -669,6 +818,26 @@ class MigrationServiceAsyncClient:
     ) -> pagers.ListMigrationSubtasksAsyncPager:
         r"""Lists previously created migration subtasks.
 
+        .. code-block::
+
+            from google.cloud import bigquery_migration_v2alpha
+
+            def sample_list_migration_subtasks():
+                # Create a client
+                client = bigquery_migration_v2alpha.MigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_migration_v2alpha.ListMigrationSubtasksRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_migration_subtasks(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.bigquery_migration_v2alpha.types.ListMigrationSubtasksRequest, dict]):
                 The request object. A request to list previously created
@@ -695,7 +864,7 @@ class MigrationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
