@@ -14,23 +14,25 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
 from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.cloud.bigquery_migration_v2alpha.services.migration_service import pagers
 from google.cloud.bigquery_migration_v2alpha.types import migration_entities
@@ -255,6 +257,73 @@ class MigrationServiceClient(metaclass=MigrationServiceClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -305,50 +374,22 @@ class MigrationServiceClient(metaclass=MigrationServiceClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, MigrationServiceTransport):
             # transport is a MigrationServiceTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -360,6 +401,15 @@ class MigrationServiceClient(metaclass=MigrationServiceClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -384,6 +434,26 @@ class MigrationServiceClient(metaclass=MigrationServiceClientMeta):
     ) -> migration_entities.MigrationWorkflow:
         r"""Creates a migration workflow.
 
+
+        .. code-block::
+
+            from google.cloud import bigquery_migration_v2alpha
+
+            def sample_create_migration_workflow():
+                # Create a client
+                client = bigquery_migration_v2alpha.MigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_migration_v2alpha.CreateMigrationWorkflowRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.create_migration_workflow(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_migration_v2alpha.types.CreateMigrationWorkflowRequest, dict]):
                 The request object. Request to create a migration
@@ -417,7 +487,7 @@ class MigrationServiceClient(metaclass=MigrationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, migration_workflow])
         if request is not None and has_flattened_params:
@@ -468,6 +538,26 @@ class MigrationServiceClient(metaclass=MigrationServiceClientMeta):
     ) -> migration_entities.MigrationWorkflow:
         r"""Gets a previously created migration workflow.
 
+
+        .. code-block::
+
+            from google.cloud import bigquery_migration_v2alpha
+
+            def sample_get_migration_workflow():
+                # Create a client
+                client = bigquery_migration_v2alpha.MigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_migration_v2alpha.GetMigrationWorkflowRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_migration_workflow(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_migration_v2alpha.types.GetMigrationWorkflowRequest, dict]):
                 The request object. A request to get a previously
@@ -494,7 +584,7 @@ class MigrationServiceClient(metaclass=MigrationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -541,6 +631,27 @@ class MigrationServiceClient(metaclass=MigrationServiceClientMeta):
     ) -> pagers.ListMigrationWorkflowsPager:
         r"""Lists previously created migration workflow.
 
+
+        .. code-block::
+
+            from google.cloud import bigquery_migration_v2alpha
+
+            def sample_list_migration_workflows():
+                # Create a client
+                client = bigquery_migration_v2alpha.MigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_migration_v2alpha.ListMigrationWorkflowsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_migration_workflows(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.bigquery_migration_v2alpha.types.ListMigrationWorkflowsRequest, dict]):
                 The request object. A request to list previously created
@@ -568,7 +679,7 @@ class MigrationServiceClient(metaclass=MigrationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -621,6 +732,23 @@ class MigrationServiceClient(metaclass=MigrationServiceClientMeta):
     ) -> None:
         r"""Deletes a migration workflow by name.
 
+
+        .. code-block::
+
+            from google.cloud import bigquery_migration_v2alpha
+
+            def sample_delete_migration_workflow():
+                # Create a client
+                client = bigquery_migration_v2alpha.MigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_migration_v2alpha.DeleteMigrationWorkflowRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_migration_workflow(request=request)
+
         Args:
             request (Union[google.cloud.bigquery_migration_v2alpha.types.DeleteMigrationWorkflowRequest, dict]):
                 The request object. A request to delete a previously
@@ -640,7 +768,7 @@ class MigrationServiceClient(metaclass=MigrationServiceClientMeta):
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -692,6 +820,24 @@ class MigrationServiceClient(metaclass=MigrationServiceClientMeta):
         signaled if the state is anything other than DRAFT or
         RUNNING.
 
+
+
+        .. code-block::
+
+            from google.cloud import bigquery_migration_v2alpha
+
+            def sample_start_migration_workflow():
+                # Create a client
+                client = bigquery_migration_v2alpha.MigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_migration_v2alpha.StartMigrationWorkflowRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.start_migration_workflow(request=request)
+
         Args:
             request (Union[google.cloud.bigquery_migration_v2alpha.types.StartMigrationWorkflowRequest, dict]):
                 The request object. A request to start a previously
@@ -711,7 +857,7 @@ class MigrationServiceClient(metaclass=MigrationServiceClientMeta):
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -757,6 +903,26 @@ class MigrationServiceClient(metaclass=MigrationServiceClientMeta):
     ) -> migration_entities.MigrationSubtask:
         r"""Gets a previously created migration subtask.
 
+
+        .. code-block::
+
+            from google.cloud import bigquery_migration_v2alpha
+
+            def sample_get_migration_subtask():
+                # Create a client
+                client = bigquery_migration_v2alpha.MigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_migration_v2alpha.GetMigrationSubtaskRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_migration_subtask(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.bigquery_migration_v2alpha.types.GetMigrationSubtaskRequest, dict]):
                 The request object. A request to get a previously
@@ -786,7 +952,7 @@ class MigrationServiceClient(metaclass=MigrationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -833,6 +999,27 @@ class MigrationServiceClient(metaclass=MigrationServiceClientMeta):
     ) -> pagers.ListMigrationSubtasksPager:
         r"""Lists previously created migration subtasks.
 
+
+        .. code-block::
+
+            from google.cloud import bigquery_migration_v2alpha
+
+            def sample_list_migration_subtasks():
+                # Create a client
+                client = bigquery_migration_v2alpha.MigrationServiceClient()
+
+                # Initialize request argument(s)
+                request = bigquery_migration_v2alpha.ListMigrationSubtasksRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_migration_subtasks(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.bigquery_migration_v2alpha.types.ListMigrationSubtasksRequest, dict]):
                 The request object. A request to list previously created
@@ -859,7 +1046,7 @@ class MigrationServiceClient(metaclass=MigrationServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
